# frozen_string_literal: true

module Bulkrax
  class CrcFolderComplexModalityEntry < CrcFolderEntry
    include ComplexHelper
    def build
      begin
        raise ComplexSessionCreatedError unless session_created?

        complex_modality = ComplexModality.new(modality_title: validate_and_fix_title, modality: self.raw_metadata['modality'])
        complex_modality.source_identifier = identifier
        complex_modality.parent_source_identifier = self.raw_metadata['parents']
        complex_modality.is_imported = true
        complex_modality.save!
      rescue RSolr::Error::Http, ComplexSessionCreatedError => e
        raise e
      rescue StandardError => e
        status_info(e)
      else
        status_info
      ensure
        self.save!
      end
    end

    def factory_class
      ComplexModality
    end

    def session_created?
      ComplexSession.find_by(source_identifier: self.raw_metadata['parents'])
    end

    def validate_and_fix_title
      modality_title = sanitize_title(self.raw_metadata['title'])
      modality_title = modality_title.rjust(3, '0')  if modality_title.length < 3
      modality_title
    end
  end
end
