require 'rails_helper'

RSpec.describe RelationshipService do
  let(:service) { described_class.new }

  describe "#select_active_options" do
    it "returns active terms" do
      expect(service.select_active_options).to include(
        ["is cited by", "isCitedBy"],
        [ "is supplement to", "isSupplementTo"])
    end
  end

  describe "find_by_id" do
    it "returns active term matching id" do
      expect(service.find_by_id('isCitedBy')).to eq({
        "label" => "is cited by",
        "id" => "isCitedBy",
        "active" => true
      })
    end
  end

  describe "find_by_label" do
    it "returns active term  matching label" do
      expect(service.find_by_label('is continued by')).to eq({
        "label" => "is continued by",
        "id" => "isContinuedBy",
        "active" => true
      })
    end
  end

  describe "find_by_id_or_label" do
    it "returns active term matching id or label" do
      expect(service.find_by_id_or_label('is metadata for')).to eq({
        "active"=>true,
        "id"=>"isMetadataFor",
        "label"=>"is metadata for"
      })
      expect(service.find_by_id_or_label('isMetadataFor')).to eq({
        "id"=>"isMetadataFor",
        "label"=>"is metadata for",
        "active" => true
      })
    end
  end
end
